@@ -11,7 +11,7 @@ from urllib.parse import unquote
 import click
 from pyppeteer import launch
 
-__version__ = '0.1.10'
+__version__ = '0.1.12'
 
 # Символы запрещенные в именах файлов в Linux, Mac и Windows
 UNSAFE_CHARACTERS = re.compile(r'[\\/:*?"<>|]+')
@@ -110,14 +110,6 @@ def print_version(ctx: click.Context, param: click.Option, value: Any) -> None:
 
 
 @click.command(help="capture snapshot of webpage")
-@click.option(
-    '-v',
-    '--version',
-    is_flag=True,
-    callback=print_version,
-    expose_value=False,
-    is_eager=True,
-)
 @click.option(
     '-i', '--input', help="input filename", type=click.File('r+'), default='-'
 )
@@ -175,6 +167,16 @@ def print_version(ctx: click.Context, param: click.Option, value: Any) -> None:
     callback=lambda ctx, param, value: value.upper(),
     default='warning',
 )
+@click.option(
+    '-v',
+    '--version',
+    help="print version",
+    is_flag=True,
+    callback=print_version,
+    expose_value=False,
+    is_eager=True,
+    show_default=False,
+)
 def websnapshot(
     input: TextIO,
     output: str,
